====
RLTG
====


.. image:: https://img.shields.io/pypi/v/rltg.svg
        :target: https://pypi.python.org/pypi/rltg

.. image:: https://img.shields.io/travis/MarcoFavorito/rltg.svg
        :target: https://travis-ci.org/MarcoFavorito/rltg

.. image:: https://readthedocs.org/projects/rltg/badge/?version=latest
        :target: https://rltg.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/MarcoFavorito/rltg/shield.svg
     :target: https://pyup.io/repos/github/MarcoFavorito/rltg/
     :alt: Updates

.. image:: https://badges.gitter.im/rltg_flloat/Lobby.svg
     :alt: Join the chat at https://gitter.im/rltg_flloat/Lobby
     :target: https://gitter.im/rltg_flloat/Lobby?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge

Framework for Reinforcement Learning with Temporal Goals defined by LDLf formulas.


* Free software: MIT license
* Documentation: https://rltg.readthedocs.io.


Features
--------

* Effective Modularization of a Reinforcement Learning system;
* Easy setup of the "training loop";
* RL algorithms (here "Brain") supported: Sarsa and QLearning multi-step
* Exploration policy supported: random policy;
* Support for temporal goal defined by LDLf formulas.

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
